/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSql.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSql/qsqltablemodel.sip"
#include <qsqltablemodel.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 37 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSql/qsqldatabase.sip"
#include <qsqldatabase.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSql/qsqlrecord.sip"
#include <qsqlrecord.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSql/qsqlindex.sip"
#include <qsqlindex.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 271 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSql/qsqlerror.sip"
#include <qsqlerror.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtSql/qsqlquery.sip"
#include <qsqlquery.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
// The capsule destructor for a QModelRoleData array.
static void qpycore_gc_modelroledata(PyObject *mrd_obj);
#line 78 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 81 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 121 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 84 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 87 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 90 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 93 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 96 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 99 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 789 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 102 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 105 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 108 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 111 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 114 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtSql/sipQtSqlQSqlTableModel.cpp"


class sipQSqlTableModel : public ::QSqlTableModel
{
public:
    sipQSqlTableModel(::QObject*, const ::QSqlDatabase&);
    virtual ~sipQSqlTableModel();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool selectRow(int) SIP_OVERRIDE;
    ::QString selectStatement() const SIP_OVERRIDE;
    ::QString orderByClause() const SIP_OVERRIDE;
    bool deleteRowFromTable(int) SIP_OVERRIDE;
    bool insertRowIntoTable(const ::QSqlRecord&) SIP_OVERRIDE;
    bool updateRowInTable(int, const ::QSqlRecord&) SIP_OVERRIDE;
    void revertRow(int) SIP_OVERRIDE;
    void setFilter(const ::QString&) SIP_OVERRIDE;
    void setSort(int, ::Qt::SortOrder) SIP_OVERRIDE;
    void setEditStrategy(::QSqlTableModel::EditStrategy) SIP_OVERRIDE;
    void setTable(const ::QString&) SIP_OVERRIDE;
    bool select() SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QModelIndex index(int, int, const ::QModelIndex&) const SIP_OVERRIDE;
    ::QModelIndex sibling(int, int, const ::QModelIndex&) const SIP_OVERRIDE;
    int rowCount(const ::QModelIndex&) const SIP_OVERRIDE;
    int columnCount(const ::QModelIndex&) const SIP_OVERRIDE;
    ::QVariant data(const ::QModelIndex&, int) const SIP_OVERRIDE;
    bool setData(const ::QModelIndex&, const ::QVariant&, int) SIP_OVERRIDE;
    ::QVariant headerData(int, ::Qt::Orientation, int) const SIP_OVERRIDE;
    bool setHeaderData(int, ::Qt::Orientation, const ::QVariant&, int) SIP_OVERRIDE;
    QMap<int, ::QVariant> itemData(const ::QModelIndex&) const SIP_OVERRIDE;
    bool setItemData(const ::QModelIndex&, const QMap<int, ::QVariant>&) SIP_OVERRIDE;
    ::QStringList mimeTypes() const SIP_OVERRIDE;
    ::QMimeData* mimeData(const ::QModelIndexList&) const SIP_OVERRIDE;
    bool dropMimeData(const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&) SIP_OVERRIDE;
    ::Qt::DropActions supportedDropActions() const SIP_OVERRIDE;
    bool insertRows(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    bool insertColumns(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    bool removeRows(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    bool removeColumns(int, int, const ::QModelIndex&) SIP_OVERRIDE;
    void fetchMore(const ::QModelIndex&) SIP_OVERRIDE;
    bool canFetchMore(const ::QModelIndex&) const SIP_OVERRIDE;
    ::Qt::ItemFlags flags(const ::QModelIndex&) const SIP_OVERRIDE;
    void sort(int, ::Qt::SortOrder) SIP_OVERRIDE;
    ::QModelIndex buddy(const ::QModelIndex&) const SIP_OVERRIDE;
    ::QModelIndexList match(const ::QModelIndex&, int, const ::QVariant&, int, ::Qt::MatchFlags) const SIP_OVERRIDE;
    ::QSize span(const ::QModelIndex&) const SIP_OVERRIDE;
    bool submit() SIP_OVERRIDE;
    void revert() SIP_OVERRIDE;
    ::Qt::DropActions supportedDragActions() const SIP_OVERRIDE;
    QHash<int, ::QByteArray> roleNames() const SIP_OVERRIDE;
    void resetInternalData() SIP_OVERRIDE;
    bool canDropMimeData(const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&) const SIP_OVERRIDE;
    bool moveRows(const ::QModelIndex&, int, int, const ::QModelIndex&, int) SIP_OVERRIDE;
    bool moveColumns(const ::QModelIndex&, int, int, const ::QModelIndex&, int) SIP_OVERRIDE;
    bool clearItemData(const ::QModelIndex&) SIP_OVERRIDE;
    void multiData(const ::QModelIndex&, ::QModelRoleDataSpan) const SIP_OVERRIDE;
    void clear() SIP_OVERRIDE;
    void queryChange() SIP_OVERRIDE;
    ::QModelIndex indexInQuery(const ::QModelIndex&) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSqlTableModel(const sipQSqlTableModel &);
    sipQSqlTableModel &operator = (const sipQSqlTableModel &);

    char sipPyMethods[57];
};

sipQSqlTableModel::sipQSqlTableModel(::QObject*a0, const ::QSqlDatabase& a1): ::QSqlTableModel(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSqlTableModel::~sipQSqlTableModel()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQSqlTableModel::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtSql_qt_metaobject(sipPySelf, sipType_QSqlTableModel);

    return ::QSqlTableModel::metaObject();
}

int sipQSqlTableModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QSqlTableModel::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtSql_qt_metacall(sipPySelf, sipType_QSqlTableModel, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQSqlTableModel::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtSql_qt_metacast(sipPySelf, sipType_QSqlTableModel, _clname, &sipCpp) ? sipCpp : ::QSqlTableModel::qt_metacast(_clname));
}

bool sipQSqlTableModel::selectRow(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_selectRow);

    if (!sipMeth)
        return ::QSqlTableModel::selectRow(a0);

    extern bool sipVH_QtSql_62(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtSql_62(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQSqlTableModel::selectStatement() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_selectStatement);

    if (!sipMeth)
        return ::QSqlTableModel::selectStatement();

    extern ::QString sipVH_QtSql_63(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSql_63(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQSqlTableModel::orderByClause() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_orderByClause);

    if (!sipMeth)
        return ::QSqlTableModel::orderByClause();

    extern ::QString sipVH_QtSql_63(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSql_63(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSqlTableModel::deleteRowFromTable(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_deleteRowFromTable);

    if (!sipMeth)
        return ::QSqlTableModel::deleteRowFromTable(a0);

    extern bool sipVH_QtSql_62(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtSql_62(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSqlTableModel::insertRowIntoTable(const ::QSqlRecord& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_insertRowIntoTable);

    if (!sipMeth)
        return ::QSqlTableModel::insertRowIntoTable(a0);

    extern bool sipVH_QtSql_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QSqlRecord&);

    return sipVH_QtSql_61(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSqlTableModel::updateRowInTable(int a0, const ::QSqlRecord& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_updateRowInTable);

    if (!sipMeth)
        return ::QSqlTableModel::updateRowInTable(a0, a1);

    extern bool sipVH_QtSql_60(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, const ::QSqlRecord&);

    return sipVH_QtSql_60(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQSqlTableModel::revertRow(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_revertRow);

    if (!sipMeth)
    {
        ::QSqlTableModel::revertRow(a0);
        return;
    }

    extern void sipVH_QtSql_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtSql_59(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSqlTableModel::setFilter(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_setFilter);

    if (!sipMeth)
    {
        ::QSqlTableModel::setFilter(a0);
        return;
    }

    extern void sipVH_QtSql_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    sipVH_QtSql_57(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSqlTableModel::setSort(int a0, ::Qt::SortOrder a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_setSort);

    if (!sipMeth)
    {
        ::QSqlTableModel::setSort(a0, a1);
        return;
    }

    extern void sipVH_QtSql_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::SortOrder);

    sipVH_QtSql_41(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQSqlTableModel::setEditStrategy(::QSqlTableModel::EditStrategy a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_setEditStrategy);

    if (!sipMeth)
    {
        ::QSqlTableModel::setEditStrategy(a0);
        return;
    }

    extern void sipVH_QtSql_58(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QSqlTableModel::EditStrategy);

    sipVH_QtSql_58(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSqlTableModel::setTable(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_setTable);

    if (!sipMeth)
    {
        ::QSqlTableModel::setTable(a0);
        return;
    }

    extern void sipVH_QtSql_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    sipVH_QtSql_57(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSqlTableModel::select()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_select);

    if (!sipMeth)
        return ::QSqlTableModel::select();

    extern bool sipVH_QtSql_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSql_7(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSqlTableModel::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QSqlTableModel::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtSql_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSql_1(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSqlTableModel::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QSqlTableModel::connectNotify(a0);
        return;
    }

    extern void sipVH_QtSql_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtSql_1(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSqlTableModel::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QSqlTableModel::customEvent(a0);
        return;
    }

    extern void sipVH_QtSql_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtSql_2(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSqlTableModel::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QSqlTableModel::childEvent(a0);
        return;
    }

    extern void sipVH_QtSql_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtSql_3(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSqlTableModel::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QSqlTableModel::timerEvent(a0);
        return;
    }

    extern void sipVH_QtSql_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtSql_4(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSqlTableModel::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QSqlTableModel::eventFilter(a0, a1);

    extern bool sipVH_QtSql_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtSql_5(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQSqlTableModel::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QSqlTableModel::event(a0);

    extern bool sipVH_QtSql_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtSql_6(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QModelIndex sipQSqlTableModel::index(int a0, int a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[19]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_index);

    if (!sipMeth)
        return ::QSqlTableModel::index(a0, a1, a2);

    extern ::QModelIndex sipVH_QtSql_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtSql_25(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QModelIndex sipQSqlTableModel::sibling(int a0, int a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[20]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sibling);

    if (!sipMeth)
        return ::QSqlTableModel::sibling(a0, a1, a2);

    extern ::QModelIndex sipVH_QtSql_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtSql_25(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

int sipQSqlTableModel::rowCount(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_rowCount);

    if (!sipMeth)
        return ::QSqlTableModel::rowCount(a0);

    extern int sipVH_QtSql_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtSql_27(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQSqlTableModel::columnCount(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[22]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_columnCount);

    if (!sipMeth)
        return ::QSqlTableModel::columnCount(a0);

    extern int sipVH_QtSql_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtSql_27(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQSqlTableModel::data(const ::QModelIndex& a0, int a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[23]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_data);

    if (!sipMeth)
        return ::QSqlTableModel::data(a0, a1);

    extern ::QVariant sipVH_QtSql_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int);

    return sipVH_QtSql_29(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQSqlTableModel::setData(const ::QModelIndex& a0, const ::QVariant& a1, int a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_setData);

    if (!sipMeth)
        return ::QSqlTableModel::setData(a0, a1, a2);

    extern bool sipVH_QtSql_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QVariant&, int);

    return sipVH_QtSql_30(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QVariant sipQSqlTableModel::headerData(int a0, ::Qt::Orientation a1, int a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[25]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_headerData);

    if (!sipMeth)
        return ::QSqlTableModel::headerData(a0, a1, a2);

    extern ::QVariant sipVH_QtSql_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::Orientation, int);

    return sipVH_QtSql_31(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQSqlTableModel::setHeaderData(int a0, ::Qt::Orientation a1, const ::QVariant& a2, int a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_setHeaderData);

    if (!sipMeth)
        return ::QSqlTableModel::setHeaderData(a0, a1, a2, a3);

    extern bool sipVH_QtSql_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::Orientation, const ::QVariant&, int);

    return sipVH_QtSql_32(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

QMap<int, ::QVariant> sipQSqlTableModel::itemData(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[27]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_itemData);

    if (!sipMeth)
        return ::QSqlTableModel::itemData(a0);

    extern QMap<int, ::QVariant> sipVH_QtSql_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtSql_33(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSqlTableModel::setItemData(const ::QModelIndex& a0, const QMap<int, ::QVariant>& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_setItemData);

    if (!sipMeth)
        return ::QSqlTableModel::setItemData(a0, a1);

    extern bool sipVH_QtSql_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const QMap<int, ::QVariant>&);

    return sipVH_QtSql_34(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QStringList sipQSqlTableModel::mimeTypes() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[29]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mimeTypes);

    if (!sipMeth)
        return ::QSqlTableModel::mimeTypes();

    extern ::QStringList sipVH_QtSql_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSql_22(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QMimeData* sipQSqlTableModel::mimeData(const ::QModelIndexList& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[30]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mimeData);

    if (!sipMeth)
        return ::QSqlTableModel::mimeData(a0);

    extern ::QMimeData* sipVH_QtSql_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndexList&);

    return sipVH_QtSql_35(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSqlTableModel::dropMimeData(const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_dropMimeData);

    if (!sipMeth)
        return ::QSqlTableModel::dropMimeData(a0, a1, a2, a3, a4);

    extern bool sipVH_QtSql_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&);

    return sipVH_QtSql_36(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

::Qt::DropActions sipQSqlTableModel::supportedDropActions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[32]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportedDropActions);

    if (!sipMeth)
        return ::QSqlTableModel::supportedDropActions();

    extern ::Qt::DropActions sipVH_QtSql_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSql_37(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSqlTableModel::insertRows(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_insertRows);

    if (!sipMeth)
        return ::QSqlTableModel::insertRows(a0, a1, a2);

    extern bool sipVH_QtSql_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtSql_38(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQSqlTableModel::insertColumns(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_insertColumns);

    if (!sipMeth)
        return ::QSqlTableModel::insertColumns(a0, a1, a2);

    extern bool sipVH_QtSql_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtSql_38(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQSqlTableModel::removeRows(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_removeRows);

    if (!sipMeth)
        return ::QSqlTableModel::removeRows(a0, a1, a2);

    extern bool sipVH_QtSql_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtSql_38(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQSqlTableModel::removeColumns(int a0, int a1, const ::QModelIndex& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_removeColumns);

    if (!sipMeth)
        return ::QSqlTableModel::removeColumns(a0, a1, a2);

    extern bool sipVH_QtSql_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int, const ::QModelIndex&);

    return sipVH_QtSql_38(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQSqlTableModel::fetchMore(const ::QModelIndex& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_fetchMore);

    if (!sipMeth)
    {
        ::QSqlTableModel::fetchMore(a0);
        return;
    }

    extern void sipVH_QtSql_39(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    sipVH_QtSql_39(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSqlTableModel::canFetchMore(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[38]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_canFetchMore);

    if (!sipMeth)
        return ::QSqlTableModel::canFetchMore(a0);

    extern bool sipVH_QtSql_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtSql_28(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::Qt::ItemFlags sipQSqlTableModel::flags(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[39]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_flags);

    if (!sipMeth)
        return ::QSqlTableModel::flags(a0);

    extern ::Qt::ItemFlags sipVH_QtSql_40(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtSql_40(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSqlTableModel::sort(int a0, ::Qt::SortOrder a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_sort);

    if (!sipMeth)
    {
        ::QSqlTableModel::sort(a0, a1);
        return;
    }

    extern void sipVH_QtSql_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, ::Qt::SortOrder);

    sipVH_QtSql_41(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QModelIndex sipQSqlTableModel::buddy(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[41]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_buddy);

    if (!sipMeth)
        return ::QSqlTableModel::buddy(a0);

    extern ::QModelIndex sipVH_QtSql_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtSql_26(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QModelIndexList sipQSqlTableModel::match(const ::QModelIndex& a0, int a1, const ::QVariant& a2, int a3, ::Qt::MatchFlags a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[42]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_match);

    if (!sipMeth)
        return ::QSqlTableModel::match(a0, a1, a2, a3, a4);

    extern ::QModelIndexList sipVH_QtSql_42(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, const ::QVariant&, int, ::Qt::MatchFlags);

    return sipVH_QtSql_42(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

::QSize sipQSqlTableModel::span(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[43]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_span);

    if (!sipMeth)
        return ::QSqlTableModel::span(a0);

    extern ::QSize sipVH_QtSql_43(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtSql_43(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSqlTableModel::submit()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_submit);

    if (!sipMeth)
        return ::QSqlTableModel::submit();

    extern bool sipVH_QtSql_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSql_7(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSqlTableModel::revert()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_revert);

    if (!sipMeth)
    {
        ::QSqlTableModel::revert();
        return;
    }

    extern void sipVH_QtSql_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtSql_16(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::Qt::DropActions sipQSqlTableModel::supportedDragActions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportedDragActions);

    if (!sipMeth)
        return ::QSqlTableModel::supportedDragActions();

    extern ::Qt::DropActions sipVH_QtSql_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSql_37(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

QHash<int, ::QByteArray> sipQSqlTableModel::roleNames() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[47]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_roleNames);

    if (!sipMeth)
        return ::QSqlTableModel::roleNames();

    extern QHash<int, ::QByteArray> sipVH_QtSql_44(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtSql_44(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSqlTableModel::resetInternalData()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[48], &sipPySelf, SIP_NULLPTR, sipName_resetInternalData);

    if (!sipMeth)
    {
        ::QSqlTableModel::resetInternalData();
        return;
    }

    extern void sipVH_QtSql_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtSql_16(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQSqlTableModel::canDropMimeData(const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[49]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_canDropMimeData);

    if (!sipMeth)
        return ::QSqlTableModel::canDropMimeData(a0, a1, a2, a3, a4);

    extern bool sipVH_QtSql_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMimeData*, ::Qt::DropAction, int, int, const ::QModelIndex&);

    return sipVH_QtSql_36(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

bool sipQSqlTableModel::moveRows(const ::QModelIndex& a0, int a1, int a2, const ::QModelIndex& a3, int a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[50], &sipPySelf, SIP_NULLPTR, sipName_moveRows);

    if (!sipMeth)
        return ::QSqlTableModel::moveRows(a0, a1, a2, a3, a4);

    extern bool sipVH_QtSql_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int, const ::QModelIndex&, int);

    return sipVH_QtSql_45(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

bool sipQSqlTableModel::moveColumns(const ::QModelIndex& a0, int a1, int a2, const ::QModelIndex& a3, int a4)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[51], &sipPySelf, SIP_NULLPTR, sipName_moveColumns);

    if (!sipMeth)
        return ::QSqlTableModel::moveColumns(a0, a1, a2, a3, a4);

    extern bool sipVH_QtSql_45(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int, const ::QModelIndex&, int);

    return sipVH_QtSql_45(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

bool sipQSqlTableModel::clearItemData(const ::QModelIndex& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[52], &sipPySelf, SIP_NULLPTR, sipName_clearItemData);

    if (!sipMeth)
        return ::QSqlTableModel::clearItemData(a0);

    extern bool sipVH_QtSql_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtSql_28(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSqlTableModel::multiData(const ::QModelIndex& a0, ::QModelRoleDataSpan a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[53]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_multiData);

    if (!sipMeth)
    {
        ::QSqlTableModel::multiData(a0, a1);
        return;
    }

    extern void sipVH_QtSql_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, ::QModelRoleDataSpan);

    sipVH_QtSql_46(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQSqlTableModel::clear()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[54], &sipPySelf, SIP_NULLPTR, sipName_clear);

    if (!sipMeth)
    {
        ::QSqlTableModel::clear();
        return;
    }

    extern void sipVH_QtSql_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtSql_16(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQSqlTableModel::queryChange()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[55], &sipPySelf, SIP_NULLPTR, sipName_queryChange);

    if (!sipMeth)
    {
        ::QSqlTableModel::queryChange();
        return;
    }

    extern void sipVH_QtSql_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtSql_16(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QModelIndex sipQSqlTableModel::indexInQuery(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[56]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_indexInQuery);

    if (!sipMeth)
        return ::QSqlTableModel::indexInQuery(a0);

    extern ::QModelIndex sipVH_QtSql_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtSql_26(sipGILState, sipImportedVirtErrorHandlers_QtSql_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSqlTableModel_select, "select(self) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_select(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_select(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::select() : sipCpp->select());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_select, doc_QSqlTableModel_select);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_setTable, "setTable(self, tableName: str|None)");

extern "C" {static PyObject *meth_QSqlTableModel_setTable(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_setTable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QString, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QSqlTableModel::setTable(*a0) : sipCpp->setTable(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_setTable, doc_QSqlTableModel_setTable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_tableName, "tableName(self) -> str");

extern "C" {static PyObject *meth_QSqlTableModel_tableName(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_tableName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->tableName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_tableName, doc_QSqlTableModel_tableName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_flags, "flags(self, index: QModelIndex) -> Qt.ItemFlag");

extern "C" {static PyObject *meth_QSqlTableModel_flags(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::Qt::ItemFlags*sipRes;

            sipRes = new ::Qt::ItemFlags((sipSelfWasArg ? sipCpp->::QSqlTableModel::flags(*a0) : sipCpp->flags(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_ItemFlag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_flags, doc_QSqlTableModel_flags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_data, "data(self, idx: QModelIndex, role: int = Qt.DisplayRole) -> Any");

extern "C" {static PyObject *meth_QSqlTableModel_data(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_data(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        int a1 = Qt::DisplayRole;
        const ::QSqlTableModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|i", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QModelIndex, &a0, &a1))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QSqlTableModel::data(*a0, a1) : sipCpp->data(*a0, a1)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_data, doc_QSqlTableModel_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_setData, "setData(self, index: QModelIndex, value: Any, role: int = Qt.EditRole) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_setData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_setData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QVariant* a1;
        int a1State = 0;
        int a2 = Qt::EditRole;
        ::QSqlTableModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9J1|i", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QModelIndex, &a0, sipType_QVariant, &a1, &a1State, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::setData(*a0, *a1, a2) : sipCpp->setData(*a0, *a1, a2));
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_setData, doc_QSqlTableModel_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_headerData, "headerData(self, section: int, orientation: Qt.Orientation, role: int = Qt.DisplayRole) -> Any");

extern "C" {static PyObject *meth_QSqlTableModel_headerData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_headerData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::Qt::Orientation a1;
        int a2 = Qt::DisplayRole;
        const ::QSqlTableModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BiE|i", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0, sipType_Qt_Orientation, &a1, &a2))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QSqlTableModel::headerData(a0, a1, a2) : sipCpp->headerData(a0, a1, a2)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_headerData, doc_QSqlTableModel_headerData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_isDirty, "isDirty(self, index: QModelIndex) -> bool\n"
"isDirty(self) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_isDirty(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_isDirty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex* a0;
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isDirty(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDirty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_isDirty, doc_QSqlTableModel_isDirty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_clear, "clear(self)");

extern "C" {static PyObject *meth_QSqlTableModel_clear(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QSqlTableModel::clear() : sipCpp->clear());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_clear, doc_QSqlTableModel_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_setEditStrategy, "setEditStrategy(self, strategy: QSqlTableModel.EditStrategy)");

extern "C" {static PyObject *meth_QSqlTableModel_setEditStrategy(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_setEditStrategy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QSqlTableModel::EditStrategy a0;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QSqlTableModel_EditStrategy, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QSqlTableModel::setEditStrategy(a0) : sipCpp->setEditStrategy(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_setEditStrategy, doc_QSqlTableModel_setEditStrategy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_editStrategy, "editStrategy(self) -> QSqlTableModel.EditStrategy");

extern "C" {static PyObject *meth_QSqlTableModel_editStrategy(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_editStrategy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            ::QSqlTableModel::EditStrategy sipRes;

            sipRes = sipCpp->editStrategy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QSqlTableModel_EditStrategy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_editStrategy, doc_QSqlTableModel_editStrategy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_primaryKey, "primaryKey(self) -> QSqlIndex");

extern "C" {static PyObject *meth_QSqlTableModel_primaryKey(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_primaryKey(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            ::QSqlIndex*sipRes;

            sipRes = new ::QSqlIndex(sipCpp->primaryKey());

            return sipConvertFromNewType(sipRes, sipType_QSqlIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_primaryKey, doc_QSqlTableModel_primaryKey);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_database, "database(self) -> QSqlDatabase");

extern "C" {static PyObject *meth_QSqlTableModel_database(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_database(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            ::QSqlDatabase*sipRes;

            sipRes = new ::QSqlDatabase(sipCpp->database());

            return sipConvertFromNewType(sipRes, sipType_QSqlDatabase, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_database, doc_QSqlTableModel_database);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_fieldIndex, "fieldIndex(self, fieldName: str|None) -> int");

extern "C" {static PyObject *meth_QSqlTableModel_fieldIndex(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_fieldIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->fieldIndex(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_fieldIndex, doc_QSqlTableModel_fieldIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_sort, "sort(self, column: int, order: Qt.SortOrder)");

extern "C" {static PyObject *meth_QSqlTableModel_sort(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_sort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::Qt::SortOrder a1;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiE", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0, sipType_Qt_SortOrder, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QSqlTableModel::sort(a0, a1) : sipCpp->sort(a0, a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_sort, doc_QSqlTableModel_sort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_setSort, "setSort(self, column: int, order: Qt.SortOrder)");

extern "C" {static PyObject *meth_QSqlTableModel_setSort(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_setSort(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::Qt::SortOrder a1;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiE", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0, sipType_Qt_SortOrder, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QSqlTableModel::setSort(a0, a1) : sipCpp->setSort(a0, a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_setSort, doc_QSqlTableModel_setSort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_filter, "filter(self) -> str");

extern "C" {static PyObject *meth_QSqlTableModel_filter(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_filter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->filter());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_filter, doc_QSqlTableModel_filter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_setFilter, "setFilter(self, filter: str|None)");

extern "C" {static PyObject *meth_QSqlTableModel_setFilter(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_setFilter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QString, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::QSqlTableModel::setFilter(*a0) : sipCpp->setFilter(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_setFilter, doc_QSqlTableModel_setFilter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_rowCount, "rowCount(self, parent: QModelIndex = QModelIndex()) -> int");

extern "C" {static PyObject *meth_QSqlTableModel_rowCount(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_rowCount(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex& a0def = QModelIndex();
        const ::QModelIndex* a0 = &a0def;
        const ::QSqlTableModel *sipCpp;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J9", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::rowCount(*a0) : sipCpp->rowCount(*a0));

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_rowCount, doc_QSqlTableModel_rowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_removeColumns, "removeColumns(self, column: int, count: int, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_removeColumns(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_removeColumns(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = QModelIndex();
        const ::QModelIndex* a2 = &a2def;
        ::QSqlTableModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::removeColumns(a0, a1, *a2) : sipCpp->removeColumns(a0, a1, *a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_removeColumns, doc_QSqlTableModel_removeColumns);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_removeRows, "removeRows(self, row: int, count: int, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_removeRows(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_removeRows(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = QModelIndex();
        const ::QModelIndex* a2 = &a2def;
        ::QSqlTableModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::removeRows(a0, a1, *a2) : sipCpp->removeRows(a0, a1, *a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_removeRows, doc_QSqlTableModel_removeRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_insertRows, "insertRows(self, row: int, count: int, parent: QModelIndex = QModelIndex()) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_insertRows(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_insertRows(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        int a1;
        const ::QModelIndex& a2def = QModelIndex();
        const ::QModelIndex* a2 = &a2def;
        ::QSqlTableModel *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|J9", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0, &a1, sipType_QModelIndex, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::insertRows(a0, a1, *a2) : sipCpp->insertRows(a0, a1, *a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_insertRows, doc_QSqlTableModel_insertRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_insertRecord, "insertRecord(self, row: int, record: QSqlRecord) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_insertRecord(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_insertRecord(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QSqlRecord* a1;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ9", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0, sipType_QSqlRecord, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->insertRecord(a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_insertRecord, doc_QSqlTableModel_insertRecord);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_setRecord, "setRecord(self, row: int, record: QSqlRecord) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_setRecord(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_setRecord(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QSqlRecord* a1;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ9", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0, sipType_QSqlRecord, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->setRecord(a0, *a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_setRecord, doc_QSqlTableModel_setRecord);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_revertRow, "revertRow(self, row: int)");

extern "C" {static PyObject *meth_QSqlTableModel_revertRow(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_revertRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QSqlTableModel::revertRow(a0) : sipCpp->revertRow(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_revertRow, doc_QSqlTableModel_revertRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_submit, "submit(self) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_submit(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_submit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::submit() : sipCpp->submit());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_submit, doc_QSqlTableModel_submit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_revert, "revert(self)");

extern "C" {static PyObject *meth_QSqlTableModel_revert(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_revert(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QSqlTableModel::revert() : sipCpp->revert());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_revert, doc_QSqlTableModel_revert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_submitAll, "submitAll(self) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_submitAll(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_submitAll(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->submitAll();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_submitAll, doc_QSqlTableModel_submitAll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_revertAll, "revertAll(self)");

extern "C" {static PyObject *meth_QSqlTableModel_revertAll(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_revertAll(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            sipCpp->revertAll();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_revertAll, doc_QSqlTableModel_revertAll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_updateRowInTable, "updateRowInTable(self, row: int, values: QSqlRecord) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_updateRowInTable(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_updateRowInTable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        const ::QSqlRecord* a1;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "piJ9", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0, sipType_QSqlRecord, &a1))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::updateRowInTable(a0, *a1) : sipCpp->updateRowInTable(a0, *a1));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_updateRowInTable, doc_QSqlTableModel_updateRowInTable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_insertRowIntoTable, "insertRowIntoTable(self, values: QSqlRecord) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_insertRowIntoTable(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_insertRowIntoTable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QSqlRecord* a0;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QSqlRecord, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::insertRowIntoTable(*a0) : sipCpp->insertRowIntoTable(*a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_insertRowIntoTable, doc_QSqlTableModel_insertRowIntoTable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_deleteRowFromTable, "deleteRowFromTable(self, row: int) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_deleteRowFromTable(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_deleteRowFromTable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pi", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::deleteRowFromTable(a0) : sipCpp->deleteRowFromTable(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_deleteRowFromTable, doc_QSqlTableModel_deleteRowFromTable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_orderByClause, "orderByClause(self) -> str");

extern "C" {static PyObject *meth_QSqlTableModel_orderByClause(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_orderByClause(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QSqlTableModel::orderByClause() : sipCpp->orderByClause()));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_orderByClause, doc_QSqlTableModel_orderByClause);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_selectStatement, "selectStatement(self) -> str");

extern "C" {static PyObject *meth_QSqlTableModel_selectStatement(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_selectStatement(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QSqlTableModel::selectStatement() : sipCpp->selectStatement()));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_selectStatement, doc_QSqlTableModel_selectStatement);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_setPrimaryKey, "setPrimaryKey(self, key: QSqlIndex)");

extern "C" {static PyObject *meth_QSqlTableModel_setPrimaryKey(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_setPrimaryKey(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSqlIndex* a0;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QSqlIndex, &a0))
        {
            sipCpp->setPrimaryKey(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_setPrimaryKey, doc_QSqlTableModel_setPrimaryKey);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_indexInQuery, "indexInQuery(self, item: QModelIndex) -> QModelIndex");

extern "C" {static PyObject *meth_QSqlTableModel_indexInQuery(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_indexInQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex((sipSelfWasArg ? sipCpp->::QSqlTableModel::indexInQuery(*a0) : sipCpp->indexInQuery(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_indexInQuery, doc_QSqlTableModel_indexInQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_primaryValues, "primaryValues(self, row: int) -> QSqlRecord");

extern "C" {static PyObject *meth_QSqlTableModel_primaryValues(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_primaryValues(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pi", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0))
        {
            ::QSqlRecord*sipRes;

            sipRes = new ::QSqlRecord(sipCpp->primaryValues(a0));

            return sipConvertFromNewType(sipRes, sipType_QSqlRecord, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_primaryValues, doc_QSqlTableModel_primaryValues);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_selectRow, "selectRow(self, row: int) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_selectRow(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_selectRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::selectRow(a0) : sipCpp->selectRow(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_selectRow, doc_QSqlTableModel_selectRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_record, "record(self) -> QSqlRecord\n"
"record(self, row: int) -> QSqlRecord");

extern "C" {static PyObject *meth_QSqlTableModel_record(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_record(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSqlTableModel, &sipCpp))
        {
            ::QSqlRecord*sipRes;

            sipRes = new ::QSqlRecord(sipCpp->record());

            return sipConvertFromNewType(sipRes, sipType_QSqlRecord, SIP_NULLPTR);
        }
    }

    {
        int a0;
        const ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QSqlTableModel, &sipCpp, &a0))
        {
            ::QSqlRecord*sipRes;

            sipRes = new ::QSqlRecord(sipCpp->record(a0));

            return sipConvertFromNewType(sipRes, sipType_QSqlRecord, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_record, doc_QSqlTableModel_record);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSqlTableModel_clearItemData, "clearItemData(self, index: QModelIndex) -> bool");

extern "C" {static PyObject *meth_QSqlTableModel_clearItemData(PyObject *, PyObject *);}
static PyObject *meth_QSqlTableModel_clearItemData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QSqlTableModel)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QModelIndex* a0;
        ::QSqlTableModel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSqlTableModel, &sipCpp, sipType_QModelIndex, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QSqlTableModel::clearItemData(*a0) : sipCpp->clearItemData(*a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSqlTableModel, sipName_clearItemData, doc_QSqlTableModel_clearItemData);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSqlTableModel(void *, const sipTypeDef *);}
static void *cast_QSqlTableModel(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSqlTableModel *sipCpp = reinterpret_cast< ::QSqlTableModel *>(sipCppV);

    if (targetType == sipType_QSqlTableModel)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QSqlQueryModel)->ctd_cast(static_cast< ::QSqlQueryModel *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSqlTableModel(void *, int);}
static void release_QSqlTableModel(void *sipCppV, int)
{
    ::QSqlTableModel *sipCpp = reinterpret_cast< ::QSqlTableModel *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QSqlTableModel(Py_ssize_t);}
static void *array_QSqlTableModel(Py_ssize_t sipNrElem)
{
    return new ::QSqlTableModel[sipNrElem];
}


extern "C" {static void array_delete_QSqlTableModel(void *);}
static void array_delete_QSqlTableModel(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSqlTableModel *>(sipCpp);
}


extern "C" {static void dealloc_QSqlTableModel(sipSimpleWrapper *);}
static void dealloc_QSqlTableModel(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSqlTableModel *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSqlTableModel(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSqlTableModel(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSqlTableModel(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQSqlTableModel *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;
        const ::QSqlDatabase& a1def = QSqlDatabase();
        const ::QSqlDatabase* a1 = &a1def;

        static const char *sipKwdList[] = {
            sipName_parent,
            sipName_db,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JHJ9", sipType_QObject, &a0, sipOwner, sipType_QSqlDatabase, &a1))
        {
            sipCpp = new sipQSqlTableModel(a0, *a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSqlTableModel[] = {{21, 255, 1}};


static PyMethodDef methods_QSqlTableModel[] = {
    {sipName_clear, meth_QSqlTableModel_clear, METH_VARARGS, doc_QSqlTableModel_clear},
    {sipName_clearItemData, meth_QSqlTableModel_clearItemData, METH_VARARGS, doc_QSqlTableModel_clearItemData},
    {sipName_data, SIP_MLMETH_CAST(meth_QSqlTableModel_data), METH_VARARGS|METH_KEYWORDS, doc_QSqlTableModel_data},
    {sipName_database, meth_QSqlTableModel_database, METH_VARARGS, doc_QSqlTableModel_database},
    {sipName_deleteRowFromTable, meth_QSqlTableModel_deleteRowFromTable, METH_VARARGS, doc_QSqlTableModel_deleteRowFromTable},
    {sipName_editStrategy, meth_QSqlTableModel_editStrategy, METH_VARARGS, doc_QSqlTableModel_editStrategy},
    {sipName_fieldIndex, meth_QSqlTableModel_fieldIndex, METH_VARARGS, doc_QSqlTableModel_fieldIndex},
    {sipName_filter, meth_QSqlTableModel_filter, METH_VARARGS, doc_QSqlTableModel_filter},
    {sipName_flags, meth_QSqlTableModel_flags, METH_VARARGS, doc_QSqlTableModel_flags},
    {sipName_headerData, SIP_MLMETH_CAST(meth_QSqlTableModel_headerData), METH_VARARGS|METH_KEYWORDS, doc_QSqlTableModel_headerData},
    {sipName_indexInQuery, meth_QSqlTableModel_indexInQuery, METH_VARARGS, doc_QSqlTableModel_indexInQuery},
    {sipName_insertRecord, meth_QSqlTableModel_insertRecord, METH_VARARGS, doc_QSqlTableModel_insertRecord},
    {sipName_insertRowIntoTable, meth_QSqlTableModel_insertRowIntoTable, METH_VARARGS, doc_QSqlTableModel_insertRowIntoTable},
    {sipName_insertRows, SIP_MLMETH_CAST(meth_QSqlTableModel_insertRows), METH_VARARGS|METH_KEYWORDS, doc_QSqlTableModel_insertRows},
    {sipName_isDirty, meth_QSqlTableModel_isDirty, METH_VARARGS, doc_QSqlTableModel_isDirty},
    {sipName_orderByClause, meth_QSqlTableModel_orderByClause, METH_VARARGS, doc_QSqlTableModel_orderByClause},
    {sipName_primaryKey, meth_QSqlTableModel_primaryKey, METH_VARARGS, doc_QSqlTableModel_primaryKey},
    {sipName_primaryValues, meth_QSqlTableModel_primaryValues, METH_VARARGS, doc_QSqlTableModel_primaryValues},
    {sipName_record, meth_QSqlTableModel_record, METH_VARARGS, doc_QSqlTableModel_record},
    {sipName_removeColumns, SIP_MLMETH_CAST(meth_QSqlTableModel_removeColumns), METH_VARARGS|METH_KEYWORDS, doc_QSqlTableModel_removeColumns},
    {sipName_removeRows, SIP_MLMETH_CAST(meth_QSqlTableModel_removeRows), METH_VARARGS|METH_KEYWORDS, doc_QSqlTableModel_removeRows},
    {sipName_revert, meth_QSqlTableModel_revert, METH_VARARGS, doc_QSqlTableModel_revert},
    {sipName_revertAll, meth_QSqlTableModel_revertAll, METH_VARARGS, doc_QSqlTableModel_revertAll},
    {sipName_revertRow, meth_QSqlTableModel_revertRow, METH_VARARGS, doc_QSqlTableModel_revertRow},
    {sipName_rowCount, SIP_MLMETH_CAST(meth_QSqlTableModel_rowCount), METH_VARARGS|METH_KEYWORDS, doc_QSqlTableModel_rowCount},
    {sipName_select, meth_QSqlTableModel_select, METH_VARARGS, doc_QSqlTableModel_select},
    {sipName_selectRow, meth_QSqlTableModel_selectRow, METH_VARARGS, doc_QSqlTableModel_selectRow},
    {sipName_selectStatement, meth_QSqlTableModel_selectStatement, METH_VARARGS, doc_QSqlTableModel_selectStatement},
    {sipName_setData, SIP_MLMETH_CAST(meth_QSqlTableModel_setData), METH_VARARGS|METH_KEYWORDS, doc_QSqlTableModel_setData},
    {sipName_setEditStrategy, meth_QSqlTableModel_setEditStrategy, METH_VARARGS, doc_QSqlTableModel_setEditStrategy},
    {sipName_setFilter, meth_QSqlTableModel_setFilter, METH_VARARGS, doc_QSqlTableModel_setFilter},
    {sipName_setPrimaryKey, meth_QSqlTableModel_setPrimaryKey, METH_VARARGS, doc_QSqlTableModel_setPrimaryKey},
    {sipName_setRecord, meth_QSqlTableModel_setRecord, METH_VARARGS, doc_QSqlTableModel_setRecord},
    {sipName_setSort, meth_QSqlTableModel_setSort, METH_VARARGS, doc_QSqlTableModel_setSort},
    {sipName_setTable, meth_QSqlTableModel_setTable, METH_VARARGS, doc_QSqlTableModel_setTable},
    {sipName_sort, meth_QSqlTableModel_sort, METH_VARARGS, doc_QSqlTableModel_sort},
    {sipName_submit, meth_QSqlTableModel_submit, METH_VARARGS, doc_QSqlTableModel_submit},
    {sipName_submitAll, meth_QSqlTableModel_submitAll, METH_VARARGS, doc_QSqlTableModel_submitAll},
    {sipName_tableName, meth_QSqlTableModel_tableName, METH_VARARGS, doc_QSqlTableModel_tableName},
    {sipName_updateRowInTable, meth_QSqlTableModel_updateRowInTable, METH_VARARGS, doc_QSqlTableModel_updateRowInTable}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QSqlTableModel[] = {
    {sipName_OnFieldChange, static_cast<int>(::QSqlTableModel::OnFieldChange)},
    {sipName_OnRowChange, static_cast<int>(::QSqlTableModel::OnRowChange)},
    {sipName_OnManualSubmit, static_cast<int>(::QSqlTableModel::OnManualSubmit)},
    {0, 0}
};

PyDoc_STRVAR(doc_QSqlTableModel, "\1QSqlTableModel(parent: QObject|None = None, db: QSqlDatabase = QSqlDatabase())");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QSqlTableModel[] = {
    {"beforeDelete(int)", "\1beforeDelete(self, row: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"beforeUpdate(int,QSqlRecord&)", "\1beforeUpdate(self, row: int, record: QSqlRecord)", SIP_NULLPTR, SIP_NULLPTR},
    {"beforeInsert(QSqlRecord&)", "\1beforeInsert(self, record: QSqlRecord)", SIP_NULLPTR, SIP_NULLPTR},
    {"primeInsert(int,QSqlRecord&)", "\1primeInsert(self, row: int, record: QSqlRecord)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QSqlTableModel = {
    &::QSqlTableModel::staticMetaObject,
    signals_QSqlTableModel,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtSql_QSqlTableModel = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSqlTableModel,
        SIP_NULLPTR,
        &plugin_QSqlTableModel,
    },
    {
        sipNameNr_QSqlTableModel,
        {0, 0, 1},
        40, methods_QSqlTableModel,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QSqlTableModel, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSqlTableModel,
    -1,
    -1,
    supers_QSqlTableModel,
    SIP_NULLPTR,
    init_type_QSqlTableModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSqlTableModel,
    SIP_NULLPTR,
    array_QSqlTableModel,
    SIP_NULLPTR,
    release_QSqlTableModel,
    cast_QSqlTableModel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSqlTableModel,
    sizeof (::QSqlTableModel),
};
